# 06/2019 Lucie Kesnerova, University of Lausanne, Switzerland
# code to process raw qPCR data and calculate copynumber and cellnumber values

R.Version() # R version 3.5.0 (2018-04-23)
# set working directory
setwd("")

# load datasets
library(readxl)
dt1 <- read_excel("01_datasets.xlsx", sheet=2) # dataset 1 containing data for monthly sampled bees
dt2 <- read_excel("01_datasets.xlsx", sheet=3) # dataset 2 containing data for pooled gut samples from 14 hives
dt3 <- read_excel("01_datasets.xlsx", sheet=4) # dataset 3 containing data for experimental bees
dt4 <- read_excel("01_datasets.xlsx", sheet=5) # dataset 4 containing data for individual F N W bees (fig3)
dt <- rbind(dt1, dt2, dt3, dt4) # merge them into one dataset
rm(dt1, dt2, dt3, dt4)
dt$X__1 <- NULL # 4'906 lines
dt$Target <- factor(dt$Target)
levels(dt$Target) # "Ba"   "Bi"   "F4"   "F5"   "Fp"   "Ga"   "Sa"   "univ"
# Ba - Bartonella apis
# Bi - Bifidobacterium asteroides
# F4 - Lactobacillus Firm-4
# F5 - Lactobacillus Firm-5
# Fp - Frischella perrara
# Ga - Gilliamella apicola
# Sa - Snodgrassella alvi
# univ - universal 16S rRNA

# adjust some parameters of the dataset
dt$Cq <- as.numeric(as.character(dt$Cq))
  # NAs introduced by coercion
#dt$gut_mg <- as.numeric(as.character(dt$gut_mg))
dt$Bee_type <- as.factor(dt$Bee_type)
dt$Dataset <- as.factor(dt$Dataset)
#dt$Date <- as.numeric(dt$Date)

#### CALCULATIONS ####

# load standard curves
StdCurves <- read_excel("01_datasets.xlsx", sheet=1)
StdCurves <- StdCurves[c(1:11),c(2:6)] # select only data needed
StdCurves <- as.data.frame(StdCurves) 
# add the info from StdCurves to the data
n <- merge(dt, StdCurves)
# calculate CopyNums of actin in sample
n$actin_CopyNum <- (StdCurves[1,4]^(StdCurves[1,2] - n$actin_Cq))*200 
## CopyNum = E^(intercept - Cq), *200 ~ sample volume
# calculate CopyNums of each target
n$CopyNum <- (n$Efficiency^(n$Intercept - n$Cq))*200
## CopyNum = E^(intercept - Cq), *200 ~ gut sample volume
# push all CopyNums to '0' when the Cq value is higher than its threshold or NA (undetected)
n$CopyNum[n$Cq >= n$Threshold] <- 0
n$CopyNum[is.na(n$Cq)] <- 0
# calculate number of each bacterium in gut - divide by the number of 16S in genome of the organism
n$Target <- as.factor(n$Target)
#levels(n$Target) # "Ba"   "Bi"   "F4"   "F5"   "Fp"   "Ga"   "Sa"  "univ"
scale.factor <- c(2,2,4,4,4,4,4,1) # info about the number of 16S in corresponding genomes can be found also in Table 1
names(scale.factor) <- levels(n$Target)
n$CellNum <- NA # make new column which will be filled with values divided by 16S numbers
for(i in 1:length(scale.factor)){
  select <- which(n$Target==names(scale.factor)[i])
  n$CellNum[select] <- n$CopyNum[select]/scale.factor[i]  
}
# add information about the presence / absence of the target based on qPCR threshold of detection
n$Present <- NA 
n$Present[n$Cq > n$Threshold] <- 0 # '0' as absent
n$Present[is.na(n$Cq)] <- 0
n$Present[n$Cq < n$Threshold] <- 1 # '1' as present
# get rid of columns which are not needed anymore
n$Intercept <- NULL 
n$Slope <- NULL
n$Efficiency <- NULL
n$Threshold <- NULL

# NORMALIZE DATA with median actin value
# do it for each dataset individually
list <- split(n, n$Dataset)
dt1 <- list$mm
dt2 <- list$pool
dt3 <- list$exp
dt4 <- list$ind
rm(list,dt,n,StdCurves) # remove not needed
# calculate actin medians 
actin1 <- unique(dt1[ ,c(3,12,13)]) # select Sample_ID, actin_Cq, acin_CopyNum; 566 bees
actin1_median <- median(actin1$actin_CopyNum) # 9'665'210 
# mean(actin1$actin_CopyNum) # mean 11'103'280
actin2 <- unique(dt2[ ,c(3,12,13)]) # 42 samples
actin2_median <- median(actin2$actin_CopyNum) # 16'551'470 
actin3 <- unique(dt3[ ,c(3,12,13)]) # 41 bee
actin3_median <- median(actin3$actin_CopyNum) # 4'466'307
actin4 <- unique(dt4[ ,c(3,12,13)]) # 71 bee
actin4_median <- median(actin4$actin_CopyNum) # 6'746'320
# get normalized CopyNums and CellNums
dt1$CopyNum_norm<-round((dt1$CopyNum/dt1$actin_CopyNum)*actin1_median)
dt1$CellNum_norm<-round((dt1$CellNum/dt1$actin_CopyNum)*actin1_median)
dt2$CopyNum_norm<-round((dt2$CopyNum/dt2$actin_CopyNum)*actin2_median)
dt2$CellNum_norm<-round((dt2$CellNum/dt2$actin_CopyNum)*actin2_median)
dt3$CopyNum_norm<-round((dt3$CopyNum/dt3$actin_CopyNum)*actin3_median)
dt3$CellNum_norm<-round((dt3$CellNum/dt3$actin_CopyNum)*actin3_median)
dt4$CopyNum_norm<-round((dt4$CopyNum/dt4$actin_CopyNum)*actin4_median)
dt4$CellNum_norm<-round((dt4$CellNum/dt4$actin_CopyNum)*actin4_median)

# export datasets 
write.csv(dt1,"02_df_mm_calc.csv")
write.csv(dt2,"02_df_pool_calc.csv")
write.csv(dt3,"02_df_exp_calc.csv")
write.csv(dt4,"02_df_ind_calc.csv")
