# FILE DESCRIPTION: 0_functions.R ---------------------------------------------
#
# DESCRIPTION : User defined functions to perform permutation based t-test and linear models, as well as correlations.
#
# USAGE: 
#
#  REQUIREMENTS:  --
#  BUGS: --
#  NOTES:  ---
#  AUTHOR:  Berra Erkosar, berra.erkosarcombe@unil.ch
#  COMPANY:  UNIL, Lausanne, Switzerland


# Permutation T-Test. Function randomizes the "rpse" data "nrep" times and performs Welch's T-test. p-Value is calculated by the ratio of number of absolute t-values that is bigger that the actual t-value

ttperm<-function(rpse, v1, nrep) {
    	
    tt<-t.test(rpse~v1)  
    obs.t=data.frame(abs(tt$statistic))
    names(obs.t)<-c("v1")
    for (i in 2:nrep)  {
      rpse<-sample(rpse)
      tt2 = t.test(rpse~v1)
      obs.t[i,]<-abs(tt2$statistic)}
    pval<-NULL
    for (j in 1:ncol(obs.t)) {
      pval[j]<-sum(obs.t[,j]>=obs.t[1,j])/length(obs.t[,j]) }
    
        return(pval) 
  }
  

# Permutation linear model. Function randomizes the "rpse" data "nrep" times and performs a lineaer model. p-Value is calculated by the ratio of number of F-values that is bigger that the actualF-value

anovaFF<-function(rpse, v1, nrep) {
  lmer<-lm(rpse~v1) 
  obs.F=data.frame(t(anova(lmer)$F))
  names(obs.F)<-c("v1")
  for (i in 2:nrep)  {
    rpse<-sample(rpse)
    obs.F[i,]<-t(anova(lm(rpse~v1))$F) }
  pval<-NULL
  for (j in 1:ncol(obs.F)) {
    pval[j]<-sum(obs.F[,j]>=obs.F[1,j])/length(obs.F[,j]) }
  # optional:to show coefficients
  print(summary(lmer)[4])
  # optional: to show R^2
  print(summary(lmer)[8])
  # optional: to show adjusted R^2
  print(summary(lmer)[9])
  cat("P-value:")
  return(pval)
  cat("\n") 
}

