# FILE DESCRIPTION: 3_Plots_Fig 3 and S5.R ---------------------------------------------
#
# DESCRIPTION : Code to get Figures 3 and S5.
#
# USAGE: 
#
#  REQUIREMENTS:  Please load packages listed below.
#  BUGS: --
#  NOTES:  ---
#  AUTHOR:  Lucie Kesnerova, lucie.kesnerova@unil.ch; Olivier Emery
#  COMPANY:  UNIL, Lausanne, Switzerland

setwd("")
library(ggplot2)
library(magrittr)
library(ggpubr) # packages to add statistics directly in the plots 
#install.packages('ggbeeswarm')
library(ggbeeswarm)
library(multcomp)



#### PLOTS ####


# define custom mean function
plot.mean <- function(x) {
  m <- mean(x)
  c(y = m, ymin = m, ymax = m)
}


# Fig 3 ----------------------------------------------------------

dt <- read.csv("02_df_ind_calc.csv") # load data - individual FNW guts

#### Fig 3D - WET GUT WEIGHT ####

# functions to add number of observations and mean to the plot
give.n <- function(x){
  return(c(y = 10, label = length(x)))   # experiment with the multiplier to find the perfect position
}
plot.mean <- function(x) {
  m <- mean(x)
  c(y = m, ymin = m, ymax = m)
}

fig3D <- ggplot(dt, aes(x = Bee_type, y = gut_mg))+ 
  geom_beeswarm(aes(color=Bee_type),cex=3, size=1)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_x_discrete()+
  scale_y_continuous(limits=(c(0,80)))+
  stat_summary(data=dt, fun.data="plot.mean", 
               geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(fun.data = give.n, geom = "text") + # add number of observations
    theme_bw()
print(fig3D)
ggsave("MM_Fig3D.pdf",fig3D,height=3.5,width=4,limitsize = FALSE)


#### Fig 3E - CORRELATION WET GUT WEIGHT vs. 16S LOADS ####

corAW <- ggscatter(dt, x = "gut_mg", y = "CopyNum_norm", 
                  add = "reg.line", conf.int = TRUE, 
                  cor.coef = TRUE, cor.method = "spearman")+ 
  geom_point(aes(colour = Bee_type), size=2)+
  scale_x_continuous(breaks=c(20,30,40,50,60,70), labels = c(20,30,40,50,60,70))+
  scale_y_log10(limits=c(NA,NA), breaks=c(1e+08,1e+09), labels=c(1e+08,1e+09))+
  annotation_logticks(sides="l")+ # add logtick marks
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))
corAW
ggsave("MM_Fig3E.pdf",corAW,height=4.5,width=5.5,limitsize = FALSE)


##############
# EXPERIMENTAL BEES

dt2 <- read.csv("02_df_exp_calc.csv") # load data

dt2$X <- NULL
dt2$Target <- factor(dt2$Target)
levels(dt2$Target)

########## Fig 3F - Exp bees, gut weight

FG <- dt2[dt2$Target=="univ",]

fig3F <- ggplot(FG, aes(x = Bee_type, y = gut_mg))+ 
  geom_beeswarm(aes(color=Bee_type),cex=3, size=2)+
  scale_color_manual(values = c("SW" = "#8A8D94", "SW+P"= "#F2C945"))+
  scale_x_discrete()+
  scale_y_continuous(limits=(c(0,80)))+
  stat_summary(data=FG, fun.data="plot.mean", 
               geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(fun.data = give.n, geom = "text") + # add number of observations
  theme_bw()
print(fig3F)
ggsave("MM_Fig3F.pdf",fig3F,height=3.5,width=4,limitsize = FALSE)


#### Fig 3G - CORRELATION WET GUT WEIGHT vs. 16S LOADS ####

corAW <- ggscatter(FG, x = "gut_mg", y = "CopyNum_norm", 
                   add = "reg.line", conf.int = TRUE, 
                   cor.coef = TRUE, cor.method = "spearman")+ 
  geom_point(aes(colour = Bee_type), size=2)+
  scale_x_continuous(breaks=c(20,30,40,50,60,70), labels = c(20,30,40,50,60,70))+
  scale_y_log10(limits=c(7e+08,1e+10))+
  annotation_logticks(sides="l")+ # add logtick marks
  scale_color_manual(values = c("SW" = "#8A8D94", "SW+P"= "#F2C945"))
corAW
ggsave("MM_Fig3G.pdf",corAW,height=4.5,width=5.5,limitsize = FALSE)



#### Fig 3H - honey bee microbiota species levels according to bee type ####

dt2 <- dt2[dt2$Target!="univ",]
#dt2 <- dt2[!is.na(dt2$Sample_ID),]
# calculate SUM of the 7 phylotypes
sum <- aggregate(dt2$CellNum_norm, by=list(Category=dt2$Sample_ID,dt2$Date,dt2$Bee_type), FUN=sum) # 41 bees
colnames(sum) <- c("Sample_ID","Target","Bee_type","CellNum_norm" ) # change names
sum$Target <- "SUM"
dt2 <- dt2[, c(3,1,6,18)] #sample_ID, Target, bee_type, CellNum_norm
n <- rbind(dt2,sum)

n$Target <- factor(n$Target,levels=c("Ga", "Sa", "Bi", "F4", "F5", "Ba","Fp", "SUM")) # to plot targets in my order
levels(n$Target) 
n$x.labels <- paste(n$Bee_type, n$Target, sep = "\n")# to make subcathegories on x axis
n$x.labels <- factor(n$x.labels, levels = c("SW\nGa","SW+P\nGa","SW\nSa","SW+P\nSa","SW\nBi","SW+P\nBi",
                                            "SW\nF4","SW+P\nF4","SW\nF5","SW+P\nF5","SW\nBa","SW+P\nBa",
                                            "SW\nFp","SW+P\nFp","SW\nSUM","SW+P\nSUM"))  # give it my order
n <-n[n$CellNum_norm!=0,] # remove undetected values

fig3H = ggplot(data = n, aes(x = x.labels, y = CellNum_norm)) + 
  geom_beeswarm(aes(color=Bee_type),cex=1, size=1.8)+
  scale_color_manual(values = c("SW" = "#8A8D94", "SW+P"= "#F2C945"))+
  scale_y_log10(name = "Corrected number of bacteria", 
                breaks=c(1e+04,1e+05,1e+06,1e+07,1e+08,1e+09,1e+10),
                labels=c(1e+04,1e+05,1e+06,1e+07,1e+08,1e+09,1e+10),
                limits=c(8000,2e+10)) + # logarithmic scale
  scale_x_discrete()+ 
  stat_summary(data=n, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()
fig3H
ggsave("MM_Fig3H.pdf",fig3H,height=4,width=9,limitsize = FALSE)
# 5x Ba missing in CW
# 8x Fp missing in CW




# Fig S5 ----------------------------------------------------------

dt <- read.csv("02_df_pool_calc.csv") # load data

dt$Target <- factor(dt$Target)
levels(dt$Target)
dt_univ <- dt[dt$Target=="univ",]
dt <- dt[dt$Target!="univ",]


#### Fig S5A - honey bee microbiota species levels according to bee type ####

sum <- aggregate(dt$CellNum_norm, by=list(Category=dt$Sample_ID,dt$Bee_type), FUN=sum) # 42 bees
colnames(sum) <- c("Sample_ID","Bee_type","CellNum_norm" ) # change names
sum$Target <- "SUM"
dt2 <- merge(dt,sum, all=T)

dt2$Target <- factor(dt2$Target,levels=c("Ga", "Sa", "Bi", "F4", "F5", "Ba","Fp", "SUM")) # to plot targets in my order
levels(dt2$Target) 
dt2$x.labels <- paste(dt2$Bee_type, dt2$Target, sep = "\n")# to make subcathegories on x axis
dt2$x.labels <- factor(dt2$x.labels, levels = c("F\nGa","N\nGa","W\nGa",
                                                "F\nSa","N\nSa","W\nSa","F\nBi","N\nBi","W\nBi",
                                                "F\nF4","N\nF4","W\nF4","F\nF5","N\nF5","W\nF5",
                                                "F\nBa","N\nBa","W\nBa","F\nFp","N\nFp","W\nFp","F\nSUM","N\nSUM","W\nSUM"))  # give it my order

figS5A = ggplot(data = dt2, aes(x = x.labels, y = CellNum_norm)) + 
  geom_beeswarm(aes(color=Bee_type),cex=1, size=1.5)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_log10(name = "Corrected number of bacteria", 
                breaks=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(5e+04,2e+09)) + # logarithmic scale
  scale_x_discrete()+ 
  stat_summary(data=dt2, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()
figS5A
ggsave("MM_FigS5A.pdf", figS5A,height=3.5,width=7,limitsize = FALSE)



#### Fig S5C - 100% stacked barplots ####

#Create a custom color scale
dt$Target <- factor(dt$Target,levels=c("Fp","Ba","F5","F4","Bi","Sa","Ga")) # to plot Targets in barplot everytime in the same order
levels(dt$Target) # "Fp","Ba","F5","F4","Bi","Sa","Ga"
cols=c("#D55E00","#F0E442","#0072B2","#56B4E9","#009E73","#CC79A7","#E69F00")

library(scales)
#PLOT 100% STACKED BARPLOTS for each bee - RELATIVE COMMUNITY PROFILE
figS5C <- ggplot(dt, aes(x = Sample_ID, y = CellNum_norm, fill = Target))+
  geom_bar(position = "fill",stat = "identity") +
  scale_y_continuous(labels = percent_format())+
  scale_fill_manual(values = cols)+
  facet_grid(. ~ Bee_type, space = "free_x", scales = "free")+
  theme(panel.background = element_blank(),axis.text.x=element_text(angle=90,hjust=1,vjust=0.5),
        legend.key.size = unit(0.5, "cm"), legend.text = element_text(size=8),legend.title = element_text(size=14))
print(figS5C)
ggsave("MM_FigS5C.pdf", figS5C,height=4,width=10,limitsize = FALSE)

# plot sum numbers by sample to be added into the carpet plot
FigX <- ggplot(data = dt2[dt2$Target=="SUM",], aes(x = Sample_ID, y = CellNum_norm)) + 
  geom_point(, shape=18,size=3)+
  scale_y_log10(limits=c(1e+07,1.5e+09)) + # logarithmic scale
  facet_grid(. ~ Bee_type, space = "free_x", scales = "free")+
  scale_x_discrete()+ 
  theme_bw()
FigX
ggsave("MM_FigS5C_diamonds.pdf",FigX,height=4,width=6,limitsize = FALSE)



